pygeodesy.geod3solve.Geodesic3Solve

Package pygeodesy :: Module geod3solve :: Class Geodesic3Solve |
[frames] | no frames]

# Class Geodesic3Solve

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
    solveBase._SolveCapsBase --+
                               |
            solveBase._SolveBase --+
                                   |
               solveBase._Solve3Base --+
                                       |
                     _Geodesic3SolveBase --+
                                           |
                                          Geodesic3Solve

Wrapper to invoke Karney's Geod3Solve as a `triaxial` version of Karney's Python class Geodesic.

Notes:

- Use property `GeodSolve` or env variable `PYGEODESY_GEOD3SOLVE` to specify the (fully qualified) path to the `Geod3Solve` executable.
- This `geodesic` is intended for testing purposes only, it invokes the `GeodSolve` executable for every method call.

Instance Methods
__init__(self, triaxial3=Triaxial3(name='WGS84_3r', a=6378172, b=6378102, c=6356752, k2`...`, path='', **name) New `Solve` instance. |
Direct(self, bet1, omg1, alp1, s12, outmask=`'``UNUSED``'`, **unit) Return the `Direct` result at distance `s12`. |
DirectLine(self, bet1, omg1, alp1, caps=32671, **unit_name) Set up a GeodesicLine3Solve to compute several points on a single geodesic. |
Line(self, bet1, omg1, alp1, caps=32671, **unit_name) Set up a GeodesicLine3Solve to compute several points on a single geodesic. |
Inverse(self, bet1, omg1, bet2, omg2, outmask=`'``UNUSED``'`, **unit) Return the `Inverse` result. |
InverseLine(self, bet1, omg1, bet2, omg2, caps=32671, **unit_name) Set up a GeodesicLine3Solve to compute several points on a single geodesic. |
toStr(self, **prec_sep_other) Return this `Geodesic3Solve` as string. |
Inherited from `solveBase._SolveCapsBase`: `invokat`, `invoke`, `linelimit` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `_Geodesic3SolveBase`: `datum`, `ellipsoid`, `f`, `flattening` Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| triaxial3 Get the triaxial (`Triaxial3`).
Inherited from `_Geodesic3SolveBase`: `Geod3Solve`, `a`, `b`, `c` Inherited from `solveBase._SolveBase`: `reverse2`, `unroll` Inherited from `solveBase._SolveCapsBase`: `Exact`, `invokation`, `prec`, `status`, `verbose`, `version` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, triaxial3=Triaxial3(name='WGS84_3r', a=6378172, b=6378102, c=6356752, k2`...`, path='', **name) (Constructor) |
New `Solve` instance. Arguments: `triaxial3` - A triaxial (Triaxial3), default `Triaxial3s.WGS84_3r`. `path` - Optionally, the (fully qualified) path to the `GeodSolve` or `RhumbSolve` executable (`filename`). `name` - Optional `name=NN` (`str`). Raises: `TypeError` - Invalid `a_ellipsoid` or `f`. Overrides: object.__init__

### DirectLine (self, bet1, omg1, alp1, caps=32671, **unit_name) |
Set up a GeodesicLine3Solve to compute several points on a single geodesic. Arguments: `bet1` - Ellipsoidal Latitude of the first point (`Ang` or `unit`). `omg1` - Ellipsoidal Longitude of the first point (`Ang` or `unit`). `alp1` - Azimuth at the first point (compass `degrees`, `Ang` or `unit`). `caps` - Desired capabilities for the GeodesicLine3Solve instance. `unit_name` - Optional `name=NN` (`str`) and scalar `unit=`Degrees (or Degrees). Returns: A GeodesicLine3Solve instance. See Also: C++ GeodesicExact.Line and Python Geodesic.Line.

### Line (self, bet1, omg1, alp1, caps=32671, **unit_name) |
Set up a GeodesicLine3Solve to compute several points on a single geodesic. Arguments: `bet1` - Ellipsoidal Latitude of the first point (`Ang` or `unit`). `omg1` - Ellipsoidal Longitude of the first point (`Ang` or `unit`). `alp1` - Azimuth at the first point (compass `degrees`, `Ang` or `unit`). `caps` - Desired capabilities for the GeodesicLine3Solve instance. `unit_name` - Optional `name=NN` (`str`) and scalar `unit=`Degrees (or Degrees). Returns: A GeodesicLine3Solve instance. See Also: C++ GeodesicExact.Line and Python Geodesic.Line.

### InverseLine (self, bet1, omg1, bet2, omg2, caps=32671, **unit_name) |
Set up a GeodesicLine3Solve to compute several points on a single geodesic. Arguments: `bet1` - Latitude of the first point (`Ang` or `unit`). `omg1` - Longitude of the first point (`Ang` or `unit`). `bet2` - Latitude of the second point (`Ang` or `unit`). `omg2` - Longitude of the second point (`Ang` or `unit`). `caps` - Desired capabilities for the GeodesicLine3Solve instance. `unit_name` - Optional `name=NN` (`str`) and scalar `unit=`Degrees (or Degrees). Returns: A GeodesicLine3Solve instance. Note: Both `bet1` and `bet2` should in the range `[-90, +90]`. See Also: C++ GeodesicExact.InverseLine and Python Geodesic.InverseLine.

### toStr (self, **prec_sep_other) |
Return this `Geodesic3Solve` as string. Arguments: `prec_sep` - See toStr. Returns: Geodesic3Solve items (`str`). Overrides: named._Named.toStr

Property Details

### triaxial3 Get the triaxial (`Triaxial3`). Get method: triaxial3(self) - Get the triaxial (`Triaxial3`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.